@@ -85,3 +85,92 @@ for (k = 0; k < dim; k++)
 for (l = 0; l < dim; l++)
   assert.equal(store.getQuads(null, null, null, prefix + l).length, dimCubed);
 console.timeEnd(TEST);
+
+console.log('N3 Store tests for sparsely connected entities');
+
+store = new N3.Store();
+TEST = `- Adding ${dimQuads} with all different IRIs`;
+console.time(TEST);
+for (let i = 0; i < dimQuads; i++) {
+  store.addQuad(
+    prefix + i,
+    prefix + i,
+    prefix + i
+  );
+}
+console.timeEnd(TEST);
+
+
+TEST = `* Retrieving all ${dimQuads} quads`;
+console.time(TEST);
+for (const quad of store.match(undefined, undefined, undefined)) {
+  assert(quad);
+}
+console.timeEnd(TEST);
+
+TEST = '* Retrieving single by subject';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(prefix + 1, undefined, undefined)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
+
+
+TEST = '* Retrieving single by predicate';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(undefined, prefix + 1, undefined)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
+
+TEST = '* Retrieving single by object';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(undefined, undefined, prefix + 1)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
+
+
+TEST = '* Retrieving single by subject-predicate';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(prefix + 1, prefix + 1, undefined)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
+
+
+TEST = '* Retrieving single by subject-object';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(prefix + 1, undefined, prefix + 1)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
+
+TEST = '* Retrieving single by predicate-object';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(undefined, prefix + 1, prefix + 1)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
+
+
+TEST = '* Retrieving single by subject-predicate-object';
+console.time(TEST);
+for (let i = 0; i < 1000000; i++) {
+  for (const quad of store.match(prefix + 1, prefix + 1, prefix + 1)) {
+    assert(quad);
+  }
+}
+console.timeEnd(TEST);
