@@ -1,71 +1,59 @@
-var DataFactory = require('../N3').DataFactory;
+import { Literal, NamedNode, Term } from '../src/';
 
-var Literal = DataFactory.internal.Literal,
-    NamedNode = DataFactory.internal.NamedNode,
-    Term = DataFactory.internal.Term;
-
-describe('Literal', function () {
-  describe('The Literal module', function () {
-    it('should be a function', function () {
+describe('Literal', () => {
+  describe('The Literal module', () => {
+    it('should be a function', () => {
       Literal.should.be.a('function');
     });
 
-    it('should make Literal objects', function () {
-      Literal().should.be.an.instanceof(Literal);
-    });
-
-    it('should make Term objects', function () {
-      Literal().should.be.an.instanceof(Term);
-    });
-
-    it('should be a Literal constructor', function () {
+    it('should be a Literal constructor', () => {
       new Literal().should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term constructor', function () {
+    it('should be a Term constructor', () => {
       new Literal().should.be.an.instanceof(Term);
     });
   });
 
-  describe('A Literal instance created from the empty string without language or datatype', function () {
-    var literal;
-    before(function () { literal = new Literal('""'); });
+  describe('A Literal instance created from the empty string without language or datatype', () => {
+    let literal;
+    before(() => { literal = new Literal('""'); });
 
-    it('should be a Literal', function () {
+    it('should be a Literal', () => {
       literal.should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term', function () {
+    it('should be a Term', () => {
       literal.should.be.an.instanceof(Term);
     });
 
-    it('should have term type "Literal"', function () {
+    it('should have term type "Literal"', () => {
       literal.termType.should.equal('Literal');
     });
 
-    it('should have the empty string as value', function () {
+    it('should have the empty string as value', () => {
       literal.should.have.property('value', '');
     });
 
-    it('should have the empty string as language', function () {
+    it('should have the empty string as language', () => {
       literal.should.have.property('language', '');
     });
 
-    it('should have xsd:string as datatype', function () {
+    it('should have xsd:string as datatype', () => {
       literal.should.have.property('datatype');
       literal.datatype.should.be.an.instanceof(NamedNode);
       literal.datatype.value.should.equal('http://www.w3.org/2001/XMLSchema#string');
     });
 
-    it('should have the quoted empty string as id', function () {
+    it('should have the quoted empty string as id', () => {
       literal.should.have.property('id', '""');
     });
 
-    it('should equal a Literal instance with the same value', function () {
+    it('should equal a Literal instance with the same value', () => {
       literal.equals(new Literal('""')).should.be.true;
     });
 
-    it('should equal an object with the same term type, value, language, and datatype', function () {
+    it('should equal an object with the same term type, value, language, and datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -74,15 +62,15 @@ describe('Literal', function () {
       }).should.be.true;
     });
 
-    it('should not equal a falsy object', function () {
+    it('should not equal a falsy object', () => {
       literal.equals(null).should.be.false;
     });
 
-    it('should not equal a Literal instance with a non-empty value', function () {
+    it('should not equal a Literal instance with a non-empty value', () => {
       literal.equals(new Literal('"x"')).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different value', function () {
+    it('should not equal an object with the same term type but a different value', () => {
       literal.equals({
         termType: 'Literal',
         value: 'x',
@@ -91,7 +79,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different language', function () {
+    it('should not equal an object with the same term type but a different language', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -100,7 +88,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different datatype', function () {
+    it('should not equal an object with the same term type but a different datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -109,7 +97,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with a different term type', function () {
+    it('should not equal an object with a different term type', () => {
       literal.equals({
         termType: 'NamedNode',
         value: '',
@@ -118,7 +106,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should provide a JSON representation', function () {
+    it('should provide a JSON representation', () => {
       literal.toJSON().should.deep.equal({
         termType: 'Literal',
         value: '',
@@ -131,45 +119,45 @@ describe('Literal', function () {
     });
   });
 
-  describe('A Literal instance created from a string without language or datatype', function () {
-    var literal;
-    before(function () { literal = new Literal('"my @^^ string"'); });
+  describe('A Literal instance created from a string without language or datatype', () => {
+    let literal;
+    before(() => { literal = new Literal('"my @^^ string"'); });
 
-    it('should be a Literal', function () {
+    it('should be a Literal', () => {
       literal.should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term', function () {
+    it('should be a Term', () => {
       literal.should.be.an.instanceof(Term);
     });
 
-    it('should have term type "Literal"', function () {
+    it('should have term type "Literal"', () => {
       literal.termType.should.equal('Literal');
     });
 
-    it('should have the text value as value', function () {
+    it('should have the text value as value', () => {
       literal.should.have.property('value', 'my @^^ string');
     });
 
-    it('should have the empty string as language', function () {
+    it('should have the empty string as language', () => {
       literal.should.have.property('language', '');
     });
 
-    it('should have xsd:string as datatype', function () {
+    it('should have xsd:string as datatype', () => {
       literal.should.have.property('datatype');
       literal.datatype.should.be.an.instanceof(NamedNode);
       literal.datatype.value.should.equal('http://www.w3.org/2001/XMLSchema#string');
     });
 
-    it('should have the quoted string as id', function () {
+    it('should have the quoted string as id', () => {
       literal.should.have.property('id', '"my @^^ string"');
     });
 
-    it('should equal a Literal instance with the same value', function () {
+    it('should equal a Literal instance with the same value', () => {
       literal.equals(new Literal('"my @^^ string"')).should.be.true;
     });
 
-    it('should equal an object with the same term type, value, language, and datatype', function () {
+    it('should equal an object with the same term type, value, language, and datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -178,15 +166,15 @@ describe('Literal', function () {
       }).should.be.true;
     });
 
-    it('should not equal a falsy object', function () {
+    it('should not equal a falsy object', () => {
       literal.equals(null).should.be.false;
     });
 
-    it('should not equal a Literal instance with another value', function () {
+    it('should not equal a Literal instance with another value', () => {
       literal.equals(new Literal('"other string"')).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different value', function () {
+    it('should not equal an object with the same term type but a different value', () => {
       literal.equals({
         termType: 'Literal',
         value: 'other string',
@@ -195,7 +183,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different language', function () {
+    it('should not equal an object with the same term type but a different language', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -204,7 +192,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different datatype', function () {
+    it('should not equal an object with the same term type but a different datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -213,7 +201,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with a different term type', function () {
+    it('should not equal an object with a different term type', () => {
       literal.equals({
         termType: 'NamedNode',
         value: 'my @^^ string',
@@ -222,7 +210,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should provide a JSON representation', function () {
+    it('should provide a JSON representation', () => {
       literal.toJSON().should.deep.equal({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -235,45 +223,45 @@ describe('Literal', function () {
     });
   });
 
-  describe('A Literal instance created from the empty string with a language', function () {
-    var literal;
-    before(function () { literal = new Literal('""@en-us'); });
+  describe('A Literal instance created from the empty string with a language', () => {
+    let literal;
+    before(() => { literal = new Literal('""@en-us'); });
 
-    it('should be a Literal', function () {
+    it('should be a Literal', () => {
       literal.should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term', function () {
+    it('should be a Term', () => {
       literal.should.be.an.instanceof(Term);
     });
 
-    it('should have term type "Literal"', function () {
+    it('should have term type "Literal"', () => {
       literal.termType.should.equal('Literal');
     });
 
-    it('should have the empty string as value', function () {
+    it('should have the empty string as value', () => {
       literal.should.have.property('value', '');
     });
 
-    it('should have the language tag as language', function () {
+    it('should have the language tag as language', () => {
       literal.should.have.property('language', 'en-us');
     });
 
-    it('should have rdf:langString as datatype', function () {
+    it('should have rdf:langString as datatype', () => {
       literal.should.have.property('datatype');
       literal.datatype.should.be.an.instanceof(NamedNode);
       literal.datatype.value.should.equal('http://www.w3.org/1999/02/22-rdf-syntax-ns#langString');
     });
 
-    it('should have the quoted empty string as id', function () {
+    it('should have the quoted empty string as id', () => {
       literal.should.have.property('id', '""@en-us');
     });
 
-    it('should equal a Literal instance with the same value', function () {
+    it('should equal a Literal instance with the same value', () => {
       literal.equals(new Literal('""@en-us')).should.be.true;
     });
 
-    it('should equal an object with the same term type, value, language, and datatype', function () {
+    it('should equal an object with the same term type, value, language, and datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -282,15 +270,15 @@ describe('Literal', function () {
       }).should.be.true;
     });
 
-    it('should not equal a falsy object', function () {
+    it('should not equal a falsy object', () => {
       literal.equals(null).should.be.false;
     });
 
-    it('should not equal a Literal instance with a non-empty value', function () {
+    it('should not equal a Literal instance with a non-empty value', () => {
       literal.equals(new Literal('"x"')).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different value', function () {
+    it('should not equal an object with the same term type but a different value', () => {
       literal.equals({
         termType: 'Literal',
         value: 'x',
@@ -299,7 +287,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different language', function () {
+    it('should not equal an object with the same term type but a different language', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -308,7 +296,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different datatype', function () {
+    it('should not equal an object with the same term type but a different datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -317,7 +305,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with a different term type', function () {
+    it('should not equal an object with a different term type', () => {
       literal.equals({
         termType: 'NamedNode',
         value: '',
@@ -326,7 +314,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should provide a JSON representation', function () {
+    it('should provide a JSON representation', () => {
       literal.toJSON().should.deep.equal({
         termType: 'Literal',
         value: '',
@@ -339,45 +327,45 @@ describe('Literal', function () {
     });
   });
 
-  describe('A Literal instance created from a string without language or datatype', function () {
-    var literal;
-    before(function () { literal = new Literal('"my @^^ string"@en-us'); });
+  describe('A Literal instance created from a string without language or datatype', () => {
+    let literal;
+    before(() => { literal = new Literal('"my @^^ string"@en-us'); });
 
-    it('should be a Literal', function () {
+    it('should be a Literal', () => {
       literal.should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term', function () {
+    it('should be a Term', () => {
       literal.should.be.an.instanceof(Term);
     });
 
-    it('should have term type "Literal"', function () {
+    it('should have term type "Literal"', () => {
       literal.termType.should.equal('Literal');
     });
 
-    it('should have the text value as value', function () {
+    it('should have the text value as value', () => {
       literal.should.have.property('value', 'my @^^ string');
     });
 
-    it('should have the language tag as language', function () {
+    it('should have the language tag as language', () => {
       literal.should.have.property('language', 'en-us');
     });
 
-    it('should have rdf:langString as datatype', function () {
+    it('should have rdf:langString as datatype', () => {
       literal.should.have.property('datatype');
       literal.datatype.should.be.an.instanceof(NamedNode);
       literal.datatype.value.should.equal('http://www.w3.org/1999/02/22-rdf-syntax-ns#langString');
     });
 
-    it('should have the quoted string as id', function () {
+    it('should have the quoted string as id', () => {
       literal.should.have.property('id', '"my @^^ string"@en-us');
     });
 
-    it('should equal a Literal instance with the same value', function () {
+    it('should equal a Literal instance with the same value', () => {
       literal.equals(new Literal('"my @^^ string"@en-us')).should.be.true;
     });
 
-    it('should equal an object with the same term type, value, language, and datatype', function () {
+    it('should equal an object with the same term type, value, language, and datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -386,15 +374,15 @@ describe('Literal', function () {
       }).should.be.true;
     });
 
-    it('should not equal a falsy object', function () {
+    it('should not equal a falsy object', () => {
       literal.equals(null).should.be.false;
     });
 
-    it('should not equal a Literal instance with another value', function () {
+    it('should not equal a Literal instance with another value', () => {
       literal.equals(new Literal('"other string"')).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different value', function () {
+    it('should not equal an object with the same term type but a different value', () => {
       literal.equals({
         termType: 'Literal',
         value: 'other string',
@@ -403,7 +391,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different language', function () {
+    it('should not equal an object with the same term type but a different language', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -412,7 +400,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different datatype', function () {
+    it('should not equal an object with the same term type but a different datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -421,7 +409,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with a different term type', function () {
+    it('should not equal an object with a different term type', () => {
       literal.equals({
         termType: 'NamedNode',
         value: 'my @^^ string',
@@ -430,7 +418,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should provide a JSON representation', function () {
+    it('should provide a JSON representation', () => {
       literal.toJSON().should.deep.equal({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -443,45 +431,45 @@ describe('Literal', function () {
     });
   });
 
-  describe('A Literal instance created from the empty string with a datatype', function () {
-    var literal;
-    before(function () { literal = new Literal('""^^http://example.org/types#type'); });
+  describe('A Literal instance created from the empty string with a datatype', () => {
+    let literal;
+    before(() => { literal = new Literal('""^^http://example.org/types#type'); });
 
-    it('should be a Literal', function () {
+    it('should be a Literal', () => {
       literal.should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term', function () {
+    it('should be a Term', () => {
       literal.should.be.an.instanceof(Term);
     });
 
-    it('should have term type "Literal"', function () {
+    it('should have term type "Literal"', () => {
       literal.termType.should.equal('Literal');
     });
 
-    it('should have the empty string as value', function () {
+    it('should have the empty string as value', () => {
       literal.should.have.property('value', '');
     });
 
-    it('should have the empty string as language', function () {
+    it('should have the empty string as language', () => {
       literal.should.have.property('language', '');
     });
 
-    it('should have the datatype', function () {
+    it('should have the datatype', () => {
       literal.should.have.property('datatype');
       literal.datatype.should.be.an.instanceof(NamedNode);
       literal.datatype.value.should.equal('http://example.org/types#type');
     });
 
-    it('should have the quoted empty string as id', function () {
+    it('should have the quoted empty string as id', () => {
       literal.should.have.property('id', '""^^http://example.org/types#type');
     });
 
-    it('should equal a Literal instance with the same value', function () {
+    it('should equal a Literal instance with the same value', () => {
       literal.equals(new Literal('""^^http://example.org/types#type')).should.be.true;
     });
 
-    it('should equal an object with the same term type, value, language, and datatype', function () {
+    it('should equal an object with the same term type, value, language, and datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -490,15 +478,15 @@ describe('Literal', function () {
       }).should.be.true;
     });
 
-    it('should not equal a falsy object', function () {
+    it('should not equal a falsy object', () => {
       literal.equals(null).should.be.false;
     });
 
-    it('should not equal a Literal instance with a non-empty value', function () {
+    it('should not equal a Literal instance with a non-empty value', () => {
       literal.equals(new Literal('"x"^^http://example.org/types#type')).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different value', function () {
+    it('should not equal an object with the same term type but a different value', () => {
       literal.equals({
         termType: 'Literal',
         value: 'x',
@@ -507,7 +495,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different language', function () {
+    it('should not equal an object with the same term type but a different language', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -516,7 +504,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different datatype', function () {
+    it('should not equal an object with the same term type but a different datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: '',
@@ -525,7 +513,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with a different term type', function () {
+    it('should not equal an object with a different term type', () => {
       literal.equals({
         termType: 'NamedNode',
         value: '',
@@ -534,7 +522,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should provide a JSON representation', function () {
+    it('should provide a JSON representation', () => {
       literal.toJSON().should.deep.equal({
         termType: 'Literal',
         value: '',
@@ -547,45 +535,45 @@ describe('Literal', function () {
     });
   });
 
-  describe('A Literal instance created from a string with a datatype', function () {
-    var literal;
-    before(function () { literal = new Literal('"my @^^ string"^^http://example.org/types#type'); });
+  describe('A Literal instance created from a string with a datatype', () => {
+    let literal;
+    before(() => { literal = new Literal('"my @^^ string"^^http://example.org/types#type'); });
 
-    it('should be a Literal', function () {
+    it('should be a Literal', () => {
       literal.should.be.an.instanceof(Literal);
     });
 
-    it('should be a Term', function () {
+    it('should be a Term', () => {
       literal.should.be.an.instanceof(Term);
     });
 
-    it('should have term type "Literal"', function () {
+    it('should have term type "Literal"', () => {
       literal.termType.should.equal('Literal');
     });
 
-    it('should have the text value as value', function () {
+    it('should have the text value as value', () => {
       literal.should.have.property('value', 'my @^^ string');
     });
 
-    it('should have the empty string as language', function () {
+    it('should have the empty string as language', () => {
       literal.should.have.property('language', '');
     });
 
-    it('should have the datatype', function () {
+    it('should have the datatype', () => {
       literal.should.have.property('datatype');
       literal.datatype.should.be.an.instanceof(NamedNode);
       literal.datatype.value.should.equal('http://example.org/types#type');
     });
 
-    it('should have the quoted string as id', function () {
+    it('should have the quoted string as id', () => {
       literal.should.have.property('id', '"my @^^ string"^^http://example.org/types#type');
     });
 
-    it('should equal a Literal instance with the same value', function () {
+    it('should equal a Literal instance with the same value', () => {
       literal.equals(new Literal('"my @^^ string"^^http://example.org/types#type')).should.be.true;
     });
 
-    it('should equal an object with the same term type, value, language, and datatype', function () {
+    it('should equal an object with the same term type, value, language, and datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -594,15 +582,15 @@ describe('Literal', function () {
       }).should.be.true;
     });
 
-    it('should not equal a falsy object', function () {
+    it('should not equal a falsy object', () => {
       literal.equals(null).should.be.false;
     });
 
-    it('should not equal a Literal instance with another value', function () {
+    it('should not equal a Literal instance with another value', () => {
       literal.equals(new Literal('"other string"^^http://example.org/types#type')).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different value', function () {
+    it('should not equal an object with the same term type but a different value', () => {
       literal.equals({
         termType: 'Literal',
         value: 'other string',
@@ -611,7 +599,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different language', function () {
+    it('should not equal an object with the same term type but a different language', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -620,7 +608,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with the same term type but a different datatype', function () {
+    it('should not equal an object with the same term type but a different datatype', () => {
       literal.equals({
         termType: 'Literal',
         value: 'my @^^ string',
@@ -629,7 +617,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should not equal an object with a different term type', function () {
+    it('should not equal an object with a different term type', () => {
       literal.equals({
         termType: 'NamedNode',
         value: 'my @^^ string',
@@ -638,7 +626,7 @@ describe('Literal', function () {
       }).should.be.false;
     });
 
-    it('should provide a JSON representation', function () {
+    it('should provide a JSON representation', () => {
       literal.toJSON().should.deep.equal({
         termType: 'Literal',
         value: 'my @^^ string',
