@@ -7,7 +7,7 @@ import {
   termFromId, termToId,
 } from '../src/';
 import namespaces from '../src/IRIs';
-import chai from 'chai';
+import chai, { expect } from 'chai';
 import { Readable } from 'readable-stream';
 import arrayifyStream from 'arrayify-stream';
 
@@ -175,7 +175,16 @@ describe('Store', () => {
 
     describe('adding a triple that did not exist yet', () => {
       it('should return true', () => {
+        store.has(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o4'))).should.be.false;
+        store.has(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o4')).should.be.false;
+        store.has(null, null, new NamedNode('o4')).should.be.false;
+
         store.addQuad('s1', 'p1', 'o4').should.be.true;
+
+        store.has(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o4'))).should.be.true;
+        store.has(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o4')).should.be.true;
+        store.has(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o4'), new DefaultGraph()).should.be.true;
+        store.has(null, null, new NamedNode('o4')).should.be.true;
       });
 
       it('should increase the size', () => {
@@ -192,7 +201,6 @@ describe('Store', () => {
 
       it('should return self', () => {
         should.equal(store.add(new Quad(new NamedNode('s2'), new NamedNode('p2'), new NamedNode('o2'))), store);
-        store.has(new Quad(new NamedNode('s2'), new NamedNode('p2'), new NamedNode('o2')));
       });
 
       it('should increase the size', () => {
@@ -1628,6 +1636,34 @@ describe('Store', () => {
       });
     });
   });
+
+  describe('handles concurrent read/write', () => {
+    let store;
+    beforeEach(() => {
+      store = new Store([
+        new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o1')),
+        new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o3')),
+      ]);
+    });
+
+    it('should include added elements in match if iteration has not yet started', () => {
+      const m = store.match(null, null, null, null);
+      store.add(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o2')));
+      [...m].should.have.length(3);
+      [...store.match(null, null, null, null)].should.have.length(3);
+    });
+
+    it('should still include results of original match after iterating while adding new data', () => {
+      const m = store.match(null, null, null, null)[Symbol.iterator]();
+      m.next().value.should.deep.equal(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o1')));
+      store.add(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o0')));
+      store.add(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o2')));
+      store.add(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o4')));
+      m.next().value.should.deep.equal(new Quad(new NamedNode('s1'), new NamedNode('p1'), new NamedNode('o3')));
+      m.next().done.should.be.true;
+      [...store.match(null, null, null, null)].should.have.length(5);
+    });
+  });
 });
 
 function alwaysTrue()  { return true;  }
