@@ -1,4 +1,4 @@
-var chai = require('chai');
+const chai = require('chai');
 global.expect = chai.expect;
 chai.should();
 chai.use(require('chai-things'));
